#!/bin/sh

XA_FILES="mvsopc mvsjes mvsca7"
XA_FILES2="mvsopc.properties mvsca7.properties mvsjes.properties mvsopc.opts mvsca7.opts mvsjes.opts ../catalog/C/mvs.cat";export XA_FILES2
USER=""; export USER
GROUP=""; export GROUP

banner()
{
	echo ""
	echo "***********************************************"
	echo "* TWS for Applications for UNIX version 8.3.0 *"
	echo "***********************************************"
	echo ""
}

print_usage()
{
	echo USAGE
	echo "$SCRIPT_NAME -u"
	echo "	prints this message"
	echo ""
	echo "$SCRIPT_NAME -user <USER> [-group <GROUP>]"
	echo "	default value for group is the primary group of the specified user"
}

# Main script begins here
banner
SCRIPT_NAME=$0;export SCRIPT_NAME
WHOAMI=`id | cut -d"(" -f2 | cut -d")" -f1`
if [ ! "$WHOAMI" = "root" ]
then
   echo "Error - You must be root to run this script."
   exit 1
fi

while [ $# -gt 0 ]
do
	CPARM=$1;export CPARM
	shift

  case $CPARM in
	-user)
		if [ $# -eq 0 ] || [ "`echo $1 | cut -c1`" = "-" ] 
		then
			echo " Error: Invalid option, specify -user <user> "
			print_usage
			exit 1
		fi

		USER=$1;export USER
		shift
	;;
	-group)
		if [ $# -eq 0 ] || [ "`echo $1 | cut -c1`" = "-" ]
		then
			echolog " Error: Invalid option, specify -group <group> "
			print_usage
			exit 1
		fi
		GROUP=$1;export GROUP
		shift
	;;
	-u|-U)
		print_usage
		exit 0
	;;
	*)
		echo "Error: $1 is an unknown option"
		print_usage
		exit 1
	;;
  esac
done


if [ -z "$USER" ]
then
	echo " Error: User is not supplied"
	print_usage
	exit 1
elif [ -z "$GROUP" ]
then
	GROUP=`id $USER | cut -d"(" -f3 | cut -d")" -f1`
else
	echo "Using user=$USER and group=$GROUP"
	echo ""
fi

for file in $XA_FILES
do
	if [ -f "$file" ]
	then
		### CREATING/MODIFYING THE OPTIONS FILES ###
		OPTIONS_FILE=$file.opts;export OPTIONS_FILE
		if [ -f "$OPTIONS_FILE" ]
		then
			echo "Creating $OPTIONS_FILE"
			rm ${OPTIONS_FILE}_{$$} > /dev/null 2>&1
			sed -e "/[LJUSER|MJUSER]/ s/\=.*/\=$USER/" $OPTIONS_FILE >> ${OPTIONS_FILE}_{$$}
			echo "Saving original $OPTIONS_FILE as ${OPTIONS_FILE}_sav"
			mv $OPTIONS_FILE ${OPTIONS_FILE}_sav
			mv ${OPTIONS_FILE}_{$$} $OPTIONS_FILE
			rm ${OPTIONS_FILE}_{$$} > /dev/null 2>&1
		else 
			echo "LJUSER=$USER" >> $OPTIONS_FILE
			echo "MJUSER=$USER" >> $OPTIONS_FILE
		fi
		echo ""
	else
		echo "* Warning file $file doesn't exist"
	fi
done

for file in $XA_FILES $XA_FILES2
do
	if [ -f "$file" ]
	then
		### CHANGING OWNERSHIP AND MODES OF FILES ###
		echo "Changing ownership and modes of file $file"
		echo chown $USER:$GROUP $file
		chown $USER:$GROUP $file
		echo chmod 755 $file
		echo ""
		chmod 755 $file
	else
		echo "* Warning file $file doesn't exist"
	fi
done


exit 0
